
#ifndef CORTEOPARAMWIDGET_H
#define CORTEOPARAMWIDGET_H

#include <QMainWindow>
#include <QtXml>
#include <QTextEdit>
#include <QPushButton>
#include <QSlider>
#include <QString>
#include <QSplashScreen>

#include "ui_CorteoParamWidget.h"

#include "techniques.h"

#include "LayerForm.h"
#include "DetectorForm.h"
#include "CalibrationForm.h"

#include "XYQt/PeriodicTable.h"

class CorteoParamWidget : public QWidget, public Ui::CorteoParamWidget 
{

  Q_OBJECT
  
private:

  QList<int>  techniqueCode;
  QStringList techniqueName;

  LayerForm * foil;
  QDialog   * foilDialog; 

  // detector tab forms
  QList<DetectorForm *> detector;

  // calibration tab forms
  QList<CalibrationForm *> calibration;

  Atom  beamElement;

  QString paramfile;

  QIcon gray, green;

  void setUseLayerIcon(int ilayer);
  void setUseDetectorIcon(int idet);
  
  bool swapLayers(int layer1, int layer2);

  // layer parameter tab forms
  QList<LayerForm *> layer;

private slots:
  void setBeam();
  void setlistFile();

  void update();

  void useLayerChanged();
  void useElementChanged();

  bool moveLayerToPrevious();
  bool moveLayerToNext();
  void moveLayerEnable(int ilayer);

  void loadFile();
  void saveFile();
  bool saveParam();
  void saveFileAs();

  void showCorteoLog();

public:
	CorteoParamWidget(QWidget * parent, int maxlayer, int maxelement, QSplashScreen * splash = 0);
  
  int  technique();
  int  stragglingType();
  void setStragglingType(int type);

  bool saveParam(QString filename);
  bool loadParam(QString filename);

  QString corteo(int ilayer, int ielement, bool *error);

  QDomElement XMLNode(QDomDocument &doc);
  void setFromNode( QDomNode n);

  bool isUsedLayer(int ilayer);
  bool isUsedElement(int ilayer, int ielement);
  bool isSimulatedElement(int ilayer, int ielement);

  double fraction(int ilayer, int ielement);

  int  numberLayer();
  int  numberElement(int ilayer);

  Atom element(int ilayer, int ielement);
  Atom beam() {return beamElement;}
  QString listFile;

public slots:

  void editFoil();
  void aboutCorteoUi();
  bool isBeamDetectionTechnique();

};

#endif // CORTEOPARAMWIDGET_H

