/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef FSAXIS_H
#define FSAXIS_H

#include <qpainter.h>
#include <math.h>

#define FS_SCALE 20.

class FSAxis
{

// class data
public:
    QString title;
    QFont titleFont;
    QColor titleColor;

    QFont labelFont;
    QColor labelColor;

    QPen framePen;  	// frame lines info
    QPen tickPen;   	// tick lines info
    QPen gridPen;   	// grid lines info

    bool isHorizontal;	// true: X axis; false: Y axis
    bool grid;      	// draw grid
    bool logAxis;     	// axis is log

    double minC, maxC;		// axis' actual (or desired) min, max

private:
    double minCgt0; // axis' actual (or desired) min greater than 0 (used by log axis)

    double min, max;			// axis' rounded  min and max
    double major, minor;  		// axis tick step (grid step = major)
    int labelPrec;    // number of digits for labels, trailing 0 suppressed
    int ntick;	      	// desired number of tick marks

    double Origin;
    double factor;

    char tickPos;  // 0: none, 1: inside,  2: outside, 3: across
    char framePos; // 0: none, 1: left(bottom), 2: right(top), 3: both
    char titlePos; // 0: none, 1: left(bottom), 2: right(top), 3: both
    char labelPos; // 0: none, 1: left(bottom), 2: right(top), 3: both


// methods
public:
    FSAxis(bool iisHorizontal, QString ttitle = QString(""));
   ~FSAxis();

    void   draw(QPainter *dc, double fsize, QRect r);
    QSize  getSize(QPainter *dc, double fsize);

    void   round();
    double nicenum(double x, bool b);
    double expt(int n);

    bool   formCalc(int MIN, int MAX);
	bool   formCalc(QRect r);
    int    logic(double p, bool linlog = false);
    double real(int p, bool linlog = false);

    void toggle( void );
    bool edit(bool *extremaChanged=0 );

// properties
public:

    double getminCgt0(){ return minCgt0; }
    bool setminCgt0( double v ){ if(v>0.)minCgt0=v; return (v>0.); }

    double getmin(){ return min; }
    double getmax(){ return max; }
    double getminor(){ return minor; }
    double getmajor(){ return major; }

    int getlabelPrec(){ return labelPrec;}
    int getntick(){ return ntick;}
    bool setntick(int n){ if(n>1) ntick = n; return (n>1); }

    char gettickPos(){ return tickPos; }
    bool settickPos(char n){ if(n>=0&&n<=3) tickPos=n; return (n>=0&&n<=3); }
    char getframePos(){ return framePos; }
    bool setframePos(char n){ if(n>=0&&n<=3) framePos=n; return (n>=0&&n<=3); }
    char gettitlePos(){ return titlePos; }
    bool settitlePos(char n){ if(n>=0&&n<=3) titlePos=n; return (n>=0&&n<=3); }
    char getlabelPos(){ return labelPos; }
    bool setlabelPos(char n){ if(n>=0&&n<=3) labelPos=n; return (n>=0&&n<=3); }

private:
    void drawTextExt(QPainter * dc, QPoint p, QString s);

};

#endif // FSAXIS_H

