/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog to specify fitting functions and parameters

#include <qvalidator.h>
#include "FSFitDialog.h"

FSFitDialog::FSFitDialog(bool iisMarker, QWidget *parent)
            : QDialog( parent )
{
    setupUi(this);

    isMarker = iisMarker;

    rbPolynomial->setChecked(true);
    connect( rbBoxCar, SIGNAL(clicked()), SLOT(disablePolate()) );
    connect( rbPolynomial, SIGNAL(clicked()), SLOT(enablePolate()) );
    connect( rbSpline, SIGNAL(clicked()), SLOT(disablePolate()) );
    if(!isMarker) disablePolate();

    QIntValidator * validator = new QIntValidator(0,20, this);
    orderEdit->setValidator(validator);

}

//
// return the type of fit:
//   1: boxcar average, 2: polynomial, 3: spline
//
int FSFitDialog::fitType( void )
{
    int op = 2;
    if(rbBoxCar->isChecked()) op=1;
    else if(rbSpline->isChecked()) op=3;

    return op;
}

int FSFitDialog::order( void )
{
    return orderEdit->text().toInt();
}

void FSFitDialog::disablePolate( void )
{
    cbInterpolate->setEnabled(false);
    cbExtrapolate->setEnabled(false);
}

void FSFitDialog::enablePolate( void )
{
    if(isMarker)
    {
        cbInterpolate->setEnabled(true);
        cbExtrapolate->setEnabled(true);
    }
}

bool FSFitDialog::isExtrapolate( void )
{
    return cbExtrapolate->isChecked();
}

bool FSFitDialog::isInterpolate( void )
{
    return cbInterpolate->isChecked();
}
