/*  
    Copyright 2007, Francois Schiettekatte

    This file is part of Corteo.

    Corteo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Corteo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Corteo.  If not, see <http://www.gnu.org/licenses/>.

*/

#include <stdio.h>
#include <stdlib.h>
#include "corteoindex.h"
#include "corteoutil.h"
#include "constants.h"

// Generate dE/dx files for all elements in all elements (part of setup)
// - for each Z from 1 to 92
//     - create a file Z.asp
//     - for each element from H to U
//        - write a SRIModule input file to have the dE/dx at DIMD energies
//        - run SRIModule
//        - read the output
//        - write the result in .asp file, appended by the Z of the element as a control data
void generateDedxTables() {
  char filename[1000];
  unsigned int i, k, Z, maxElements = (unsigned int)MostAbundantIsotope[0];
  float buf[DIMD+1];
  double m;
  char dummy[1000], dedxval[1000];
  FILE *ifpsr, *ofp, *ofpsr;

#ifdef WIN32
  char endline[] = "\n";
#else
  // in Linux, when SRModule is used with Wine, we must feed a input file containing return+linefeed
  char endline[] = "\r\n"; 
#endif
  
  for(Z=1;Z<=maxElements;Z++) {
    sprintf(filename, "data/%u.asp",Z);
    ofp = fopen(filename, "wb");
    fprintf(stdout, "Generating stopping table %s", filename);
    fflush(stdout);

    m = MostAbundantIsotope[Z];
    for(i=1; i<=maxElements; i++) {
      if(i%9==0) {
        fprintf(stdout, ".");
        fflush(stdout);
      }
      // write SRModule input file
      ofpsr = fopen("sr.in", "w");
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, "sr.out");
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, "%u %f", Z, m);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, " 0 1 0");
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, "1");
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, "%u \"X\" 1 1",i); // last 1 is target element mass, affects nuclear stopping not needed here
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, " 7 ");
      fprintf(ofpsr, endline);
      fprintf(ofpsr, endline);
      fprintf(ofpsr, " 0 0 ");
      fprintf(ofpsr, endline);

      for(k=0; k<DIMD; k++) {
        fprintf(ofpsr, "%g",Dval(k)/1000.);
        fprintf(ofpsr, endline);
      }
      fprintf(ofpsr, " 0 ");
      fclose(ofpsr);

#ifdef WIN32
      system("SRModule.exe");
#else
      system("wine SRModule.exe");
#endif

      ifpsr = fopen("sr.out", "r");
      ignoreline(ifpsr);
      ignoreline(ifpsr);
      ignoreline(ifpsr);
      ignoreline(ifpsr);
      for(k=0; k<DIMD; k++) {
        fscanf(ifpsr,"%s %s", dummy, dedxval); 
        ignoreline(ifpsr);
        buf[k] = (float)atof(dedxval);
      }
      fclose(ifpsr);

      buf[DIMD]=(float)i;
      fwrite((void*)buf, sizeof(float), (DIMD+1),ofp);
    }
    fclose(ofp);
    fprintf(stdout, "done.\n");
    fflush(stdout);
  } 
}

