/*  
    Copyright 2007, Francois Schiettekatte

    This file is part of Corteo.

    Corteo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Corteo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Corteo.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef CORTEOINDEX_H
#define CORTEOINDEX_H

// Global variables: number of errors during index fuction calls (in work if INDEX_BOUND_CHECKING is defined)
unsigned long EminErr, EmaxErr, SminErr, SmaxErr, DminErr, DmaxErr; 

#define INDEX_BOUND_CHECKING  // Perform bound cheking during index evaluation (whole program 10-15% slower).
                                // No check may result out-of-bound matrix access: crash or wrong value,

// matrix index calculation parameters
#define MINE  0.0000019073486328125f  //  minimum reduced energy = 2^(-19)
#define MAXE  2097152.f // maximum reduced energy = 2^21
#define DIME  640    // matrix dimension: (21-(-19))*2^4 (4 mantissa bits: *2^4)
#define BIASE 1728   // (127-19)*2^4: exponent bias correction while performing division by 2^(-4)
#define SHIFTE 19    // keep 4 of the 23 mantissa bits (23-4=19)

#define MINS  0.0009765625f // mimimum reduced impact parameter = 2^(-10)
#define MAXS  64.f   // maximum reduced impact parameter = 2^6
#define DIMS  256    // (6-(-10))*2^4
#define BIASS 1872   // (127-10)*2^4: exponent bias correction while performing division by 2^(-10)
#define SHIFTS 19    // keep 4 of the 23 mantissa bits (23-4=19)

#define MIND  16.f         // minimum energy (eV) for stopping power tables = 2^4
#define MAXD  1073741824.f // maximum energy (eV) for stopping power tables = 2^30 ~ 1 GeV
#define DIMD  416          //  (30-4)*2^4
#define BIASD 2096         // (127+4)*2^4: exponent bias correction while performing division by 2^10
#define SHIFTD 19          // keep 4 of the 23 mantissa bits (23-4=19)

// functions that compute an index from a value
unsigned long Eindex(float Eval);
unsigned long Sindex(float Sval);
unsigned long Dindex(float Dval);

// functions that return the value corresponding to an index
float Eval(unsigned long index);
float Sval(unsigned long index);
float Dval(unsigned long index);

#endif
